@@ -2,7 +2,6 @@
 The cache object API for implementing caches. The default is just a
 dictionary, which in turns means it is not threadsafe for writing.
 """
-
 from threading import Lock
 
 
@@ -25,10 +24,6 @@ class DictCache(BaseCache):
         self.data = init_dict or {}
 
     def get(self, key):
-        if key in self.data:
-            print('CACHE HIT: %s' % key)
-        else:
-            print('CACHE MISS: %s' % key)
         return self.data.get(key, None)
 
     def set(self, key, value):
