@@ -2,7 +2,7 @@
 Unit tests that verify our caching methods work correctly.
 """
 import pytest
-import mock
+from mock import Mock
 import datetime
 import time
 
@@ -18,20 +18,20 @@ class TestCacheControllerResponse(object):
 
     def req(self, headers=None):
         headers = headers or {}
-        return mock.Mock(full_url=self.url,  # < 1.x support
-                         url=self.url,
-                         headers=headers)
+        return Mock(full_url=self.url,  # < 1.x support
+                    url=self.url,
+                    headers=headers)
 
     def resp(self, headers=None):
         headers = headers or {}
-        return mock.Mock(status_code=200,
-                         headers=headers,
-                         request=self.req())
+        return Mock(status_code=200,
+                    headers=headers,
+                    request=self.req())
 
     @pytest.fixture()
     def cc(self):
         # Cache controller fixture
-        return CacheController(mock.Mock())
+        return CacheController(Mock())
 
     def test_no_cache_non_20x_response(self, cc):
         # No caching without some extra headers, so we add them
@@ -42,24 +42,24 @@ class TestCacheControllerResponse(object):
         no_cache_codes = [201, 300, 400, 500]
         for code in no_cache_codes:
             resp.status_code = code
-            cc.cache_response(resp)
+            cc.cache_response(Mock(), resp)
             assert not cc.cache.set.called
 
         # this should work b/c the resp is 20x
         resp.status_code = 203
-        cc.cache_response(resp)
+        cc.cache_response(self.req(), resp)
         assert cc.cache.set.called
 
     def test_no_cache_with_no_date(self, cc):
         # No date header which makes our max-age pointless
         resp = self.resp({'cache-control': 'max-age=3600'})
-        cc.cache_response(resp)
+        cc.cache_response(self.req(), resp)
 
         assert not cc.cache.set.called
 
     def test_cache_response_no_cache_control(self, cc):
         resp = self.resp()
-        cc.cache_response(resp)
+        cc.cache_response(self.req(), resp)
 
         assert not cc.cache.set.called
 
@@ -68,11 +68,11 @@ class TestCacheControllerResponse(object):
         now = datetime.datetime.utcnow().strftime(TIME_FMT)
         resp = self.resp({'cache-control': 'max-age=3600',
                           'date': now})
-        cc.cache_response(resp)
+        cc.cache_response(self.req(), resp)
         cc.cache.set.assert_called_with(self.url, resp)
 
     def test_cache_repsonse_no_store(self):
-        resp = mock.Mock()
+        resp = Mock()
         cache = DictCache({self.url: resp})
         cc = CacheController(cache)
 
@@ -81,7 +81,7 @@ class TestCacheControllerResponse(object):
         resp = self.resp({'cache-control': 'no-store'})
         assert cc.cache.get(cache_url)
 
-        cc.cache_response(resp)
+        cc.cache_response(self.req(), resp)
         assert not cc.cache.get(cache_url)
 
 
@@ -116,8 +116,8 @@ class TestCacheControlRequest(object):
 
     def test_cache_request_fresh_max_age(self):
         now = datetime.datetime.utcnow().strftime(TIME_FMT)
-        resp = mock.Mock(headers={'cache-control': 'max-age=3600',
-                                  'date': now})
+        resp = Mock(headers={'cache-control': 'max-age=3600',
+                             'date': now})
 
         cache = DictCache({self.url: resp})
         self.c.cache = cache
@@ -128,8 +128,8 @@ class TestCacheControlRequest(object):
         earlier = time.time() - 3700
         now = datetime.datetime.fromtimestamp(earlier).strftime(TIME_FMT)
 
-        resp = mock.Mock(headers={'cache-control': 'max-age=3600',
-                                  'date': now})
+        resp = Mock(headers={'cache-control': 'max-age=3600',
+                             'date': now})
         self.c.cache = DictCache({self.url: resp})
         r = self.req({})
         assert not r
@@ -138,8 +138,8 @@ class TestCacheControlRequest(object):
         later = datetime.timedelta(days=1)
         expires = (datetime.datetime.utcnow() + later).strftime(TIME_FMT)
         now = datetime.datetime.utcnow().strftime(TIME_FMT)
-        resp = mock.Mock(headers={'expires': expires,
-                                  'date': now})
+        resp = Mock(headers={'expires': expires,
+                             'date': now})
         cache = DictCache({self.url: resp})
         self.c.cache = cache
         r = self.req({})
@@ -149,8 +149,8 @@ class TestCacheControlRequest(object):
         later = datetime.timedelta(days=-1)
         expires = (datetime.datetime.utcnow() + later).strftime(TIME_FMT)
         now = datetime.datetime.utcnow().strftime(TIME_FMT)
-        resp = mock.Mock(headers={'expires': expires,
-                                  'date': now})
+        resp = Mock(headers={'expires': expires,
+                             'date': now})
         cache = DictCache({self.url: resp})
         self.c.cache = cache
         r = self.req({})
